/*! This function samples a 2D texture.*/
void Sample2DTexture_float(out float4 Sample,SSamplerTexturePair2D_float UsedSampler,float2 TexCoord){
	Sample.x=UsedSampler.Texture.Sample(UsedSampler.Sampler,TexCoord);
	Sample.yzw=float3(0.0f,0.0f,1.0f);
}
void Sample2DTexture_float2(out float4 Sample,SSamplerTexturePair2D_float2 UsedSampler,float2 TexCoord){
	Sample.xy=UsedSampler.Texture.Sample(UsedSampler.Sampler,TexCoord);
	Sample.zw=float2(0.0f,1.0f);
}
void Sample2DTexture_float3(out float4 Sample,SSamplerTexturePair2D_float3 UsedSampler,float2 TexCoord){
	Sample.xyz=UsedSampler.Texture.Sample(UsedSampler.Sampler,TexCoord);
	Sample.w=1.0f;
}
void Sample2DTexture_float4(out float4 Sample,SSamplerTexturePair2D UsedSampler,float2 TexCoord){
	Sample=UsedSampler.Texture.Sample(UsedSampler.Sampler,TexCoord);
}

/*! This function samples a cube texture.*/
/*void SampleCubeTexture(out float4 Sample,SSamplerTexturePairCube UsedSampler,float3 TexCoord){
	Sample=UsedSampler.Texture.Sample(UsedSampler.Sampler,TexCoord);
}*/


/*! This function applies an offset to a texture coordinate to account for backend-
   specific texture sampling conventions.
  \param OutOffsetTexCoord Using the notions in the specification of TexCoord, this 
		 texture coordinate provides access to a sample of the texture described by 
		 TextureSize at the texel (PixelX+IntegerOffsetX,PixelY+IntegerOffsetY) 
		 where (PixelX,PixelY) is the viewport coordinate.
  \param TexCoord A texture coordinate, which is directly related to a viewport 
		 coordinate. If the viewport has size ViewportWidth*ViewportHeight in pixels 
		 and viewport coordinates range from 0.0 to 1.0, then the texture coordinate 
		 at (ViewportX,ViewportY) should be (
		  (ViewportX*ViewportWidth+ IntegerOffsetX)*TextureSize.z,
		  (ViewportY*ViewportHeight+IntegerOffsetY)*TextureSize.w
		 ) where IntegerOffsetX,IntegerOffsetY are integer constants.
  \param TextureSize The width and hight in pixels of the texture, which is to be 
		 sampled through OutOffsetTexCoord, in x and y, the reciprocal of these 
		 sizes in z and w.
  \note The implementation of this function is backend-specific. It typically 
		amounts to one two-component multiply-add operation or less. The texture 
		should not be supersampled as this can destroy the guarantees of this 
		function.*/
void ApplyQuadTexCoordOffset(out float2 OutOffsetTexCoord,float2 TexCoord,float4 TextureSize){
#if D3D_VERSION==11
	OutOffsetTexCoord=TexCoord;
#elif D3D_VERSION==9
	OutOffsetTexCoord=TexCoord+0.5f*TextureSize.zw;
#endif
}

/*! This function converts a texture coordinate to an integer texel index to be used 
   for loads from a texture.
  \param OutTexelIndex The x and y index of the texel identified by TexCoord.
  \param TextureSize The width and hight in pixels of the texture, which is to be 
		 sampled through OutOffsetTexCoord, in x and y, the reciprocal of these 
		 sizes in z and w.*/
void ComputeTexelIndex(out int2 OutTexelIndex,float2 TexCoord,float4 TextureSize){
	OutTexelIndex=int2(TexCoord*TextureSize.xy);
}
