/*! This function copies a texture coordinate with dimension one to the right 
   register.*/
void VSPassTexCoordDim1(out float1 TexCoordOut,float1 TexCoord){
	TexCoordOut=TexCoord;
}

/*! This function copies a texture coordinate with dimension two to the right 
   register.*/
void VSPassTexCoordDim2(out float2 TexCoordOut,float2 TexCoord){
	TexCoordOut=TexCoord;
}

/*! This function copies a texture coordinate with dimension one to the right 
   register.*/
void VSPassTexCoordDim3(out float3 TexCoordOut,float3 TexCoord){
	TexCoordOut=TexCoord;
}

/*! This function copies a texture coordinate with dimension one to the right 
   register.*/
void VSPassTexCoordDim4(out float4 TexCoordOut,float4 TexCoord){
	TexCoordOut=TexCoord;
}

/*! This function computes a camera view reflection vector as used for environment 
   mapping texture coordinates in mesh space. The normal is supposed to be 
   normalized, otherwise the result will be incorrect.*/
void VSComputeReflectionVector(out float3 ReflectionVectorOut,float3 WorldSpaceNormal,float4 WorldSpacePosition,float3 WorldSpaceCameraPosition){
	float3 DifferenceVector=WorldSpacePosition.xyz-WorldSpaceCameraPosition;
	ReflectionVectorOut=normalize(DifferenceVector-(2*dot(WorldSpaceNormal,DifferenceVector))*WorldSpaceNormal);
}

/*! This function passes the projection space position of a vertex as texture 
   coordinate.*/
void VSPassProjSpacePosition(out float4 TexCoordOut,float4 ProjectionSpacePosition){
	TexCoordOut=ProjectionSpacePosition;
}

/*! This function transforms a 1D texture coordinate using a 2x2 matrix.*/
void VSTransformTexCoordDim1(out float1 TexCoordOut,float1 TexCoord,float2x2 Transformation){
	TexCoordOut.x=TexCoord.x*Transformation._11+Transformation._12;
}

/*! This function transforms a 2D texture coordinate using a 3x3 matrix.*/
void VSTransformTexCoordDim2(out float2 TexCoordOut,float2 TexCoord,float3x3 Transformation){
	TexCoordOut=mul(float3(TexCoord,1.0f),Transformation).xy;
}


/*! This function transforms a 3D texture coordinate using a 4x4 matrix.*/
void VSTransformTexCoordDim3(out float3 TexCoordOut,float3 TexCoord,float4x4 Transformation){
	TexCoordOut=mul(float4(TexCoord,1.0f),Transformation).xyz;
}

/*! This function transforms a 4D texture coordinate using a 4x4 matrix.*/
void VSTransformTexCoordDim4(out float4 TexCoordOut,float4 TexCoord,float4x4 Transformation){
	TexCoordOut=mul(TexCoord,Transformation);
}
